@@ -20,6 +20,7 @@ struct wlr_backend_impl {
 	struct wlr_session *(*get_session)(struct wlr_backend *backend);
 	clockid_t (*get_presentation_clock)(struct wlr_backend *backend);
 	int (*get_drm_fd)(struct wlr_backend *backend);
+	uint32_t (*get_buffer_caps)(struct wlr_backend *backend);
 };
 
 /**
@@ -28,5 +29,9 @@ struct wlr_backend_impl {
  */
 void wlr_backend_init(struct wlr_backend *backend,
 		const struct wlr_backend_impl *impl);
+/**
+ * Emit the destroy event and clean up common backend state.
+ */
+void wlr_backend_finish(struct wlr_backend *backend);
 
 #endif
